import moment from "moment";
import { TABLENAME } from "../config/dbEnum";
import { selectDataCountByParam, selectDataListByParam, selectDataListToPageByParam, selectOneDataByParam } from "../data/findData";
import { CHAPTER, HLDTYPE, QUESTION, TESTTYPE } from "../config/enum";
import { changeEnumValue } from "../tools/eccEnum";
import { BizError } from "../util/bizError";
import { ERRORENUM } from "../config/errorEnum";


/**
 * 登录
 * @param username 
 * @param password 
 */
export async function login(username, password) {
    let findUserData = await selectOneDataByParam(TABLENAME.超级管理员表, {username, password}, []);
    let findUser = findUserData.data;
    if (!findUser || !findUser.username) throw new BizError(ERRORENUM.账号或密码错误);
    if (findUser.password != password ) throw new BizError(ERRORENUM.账号或密码错误);

    let dataInfo = {
        username: findUser.username,
        realName: findUser.real_name,
        phone: findUser.phone,
        sex: findUser.sex,
        mail: findUser.mail,
        remark: findUser.remark
    };

    return dataInfo;
}


/**
 * 获取用户列表
 * @param card 
 * @param createStartTime 
 * @param createEndTime 
 * @param area 
 * @param current 
 * @returns 
 */
export async function getUserList(card, createStartTime, createEndTime, area, current) {
    let selectParam = {"name":{"%ne%":"362527199309194932"}, "phone":{"%ne%":"17255558888"}};
    if (card) selectParam["card"] = card;
    if (createStartTime && createEndTime) selectParam["create_time"] = {"%between%":[createStartTime, createEndTime]};
    if (area) selectParam["area"] = area;
    let findData = await selectDataListToPageByParam(TABLENAME.测试信息表, selectParam, ["infoid", "name", "card", "phone", "email", "area", "create_time", "test_type"], current, 10);
    let dataCount = await selectDataCountByParam(TABLENAME.测试信息表, selectParam);

    let dataList = [];
    findData.data.forEach( info => {
        let {infoid, name, card, phone, email, area, create_time, test_type} = info;

        dataList.push({
            infoid, name, card, phone, email, area,
            createTime: moment(create_time).format("YYYY-MM-DD"),
            testType: test_type
        })
    })
    
    return {dataList, dataCount:dataCount.data};
}


/**
 * 查看列表详情
 * @param infoid 
 * @param test_type 
 * @returns 
 */
export async function getUserInfoById(infoid, test_type) {
    let testReport = {};

    if (test_type == TESTTYPE.创业) {
        testReport = await getChuangYe(infoid);
    } else if (test_type == TESTTYPE.霍兰德) {
        testReport = await getHuoLanDe(infoid);
    }

    return testReport;
}


/**
 * 创业答题详情
 * @param infoid 
 * @returns 
 */
async function getChuangYe(infoid) {
    let findUserData = await selectOneDataByParam(TABLENAME.测试信息表, {infoid}, []);
    let findData = await selectDataListByParam(TABLENAME.测试信息记录表, {infoid}, []);
    
    let optionsInfo = [];
    let score = 0;
    for (let data = 0; data < findData.data.length; data++) {
        let info = findData.data[data];
        let {chapter, title_str, option_str} = info;
        // optionsInfo[chapter] = {};
        let title = JSON.parse(title_str);
        let option = JSON.parse(option_str);
        for (let i = 0; i < option.length; i++) {
            let optionList = option[i];
            let optionName = "";
            for (let o = 0; o < optionList.length; o++) {
                let findOption = await selectOneDataByParam(TABLENAME.题目选项表, {oid:optionList[o]}, []);
                score += findOption.data["points"];
                optionName = findOption.data["option_name"].slice(2); 
            }
            optionsInfo.push({title:title[i], option:optionName});
        }
    }
    let testReport = {
        name:findUserData.data.name,
        card:findUserData.data.card,
        phone:findUserData.data.phone,
        score,
        time: moment(new Date()).format("YYYY年MM月DD日HH时mm分"),
        report:optionsInfo,
    };

    return testReport;
}


/**
 * 霍兰德详情
 * @param infoid 
 * @returns 
 */
async function getHuoLanDe(infoid) {
    let findUserData = await selectOneDataByParam(TABLENAME.测试信息表, {infoid}, []);
    let findData = await selectDataListByParam(TABLENAME.测试信息记录表, {infoid}, []);

    let optionsInfo = {};
    for (let data = 0; data < findData.data.length; data++) {
        let info = findData.data[data];
        let {chapter, title_str, option_str} = info;
        optionsInfo[chapter] = {};
        let title = JSON.parse(title_str);
        let option = JSON.parse(option_str);
        for (let i = 0; i < option.length; i++) {
            let optionList = option[i];
            let score = 0;
            for (let o = 0; o < optionList.length; o++) {
                let findOption = await selectOneDataByParam(TABLENAME.题目选项表, {oid:optionList[o]}, []);
                score += findOption.data["points"];
            }
            optionsInfo[chapter][title[i]] = score;
        }
    }
    
    let optionData = [];
    let countInfo = {};
    for (let key in optionsInfo) {
        let maxKey = "";
        let maxValue = 0;
        for (let values in optionsInfo[key]) {
            const value = optionsInfo[key][values];
            if (value > maxValue) {
                maxKey = values;
                maxValue = value;
            }

            if(!countInfo[values]) countInfo[values] = 0
            countInfo[values] += value;
        }
        let title = changeEnumValue(CHAPTER, parseInt(key));
        let maxNum = HLDTYPE[maxKey];
        optionData.push({key:title, value:maxKey, index:maxNum});
    }
    
    let countData = [];
    for (let key in countInfo) {
        let keyNum = HLDTYPE[key];
        let keyName = changeEnumValue(QUESTION, keyNum);
        countData.push({key:keyName, value:countInfo[key]});
    }

    let sortedEntries:any = Object.entries(countInfo);
    sortedEntries.sort((a, b) => b[1] - a[1]);
    let topThreeKeys = sortedEntries.slice(0, 3).map(entry => entry[0]);
    let topThreeStr = topThreeKeys.join("");

    let findCareer = await selectOneDataByParam(TABLENAME.职业对照表, {statistics:topThreeStr}, []);

    let testReport = {
        name:findUserData.data.name,
        card:findUserData.data.card,
        phone:findUserData.data.phone,
        time: moment(new Date()).format("YYYY年MM月DD日HH时mm分"),
        report1:optionData,
        report2:countData,
        statistics:topThreeStr,
        recommend:findCareer.data.recommend
    }

    return testReport;
}


/**
 * 数据导出
 * @param card 
 * @param createStartTime 
 * @param createEndTime 
 * @param area 
 * @param current 
 * @returns 
 */
export async function outPutData(card, createStartTime, createEndTime, area) {
    let selectParam = {"name":{"%ne%":"362527199309194932"}, "phone":{"%ne%":"17255558888"}};
    // let selectParam = {};
    if (card) selectParam["card"] = card;
    if (createStartTime && createEndTime) selectParam["create_time"] = {"%between%":[createStartTime, createEndTime]};
    if (area) selectParam["area"] = area;
    let findData = await selectDataListByParam(TABLENAME.测试信息表, selectParam, ["infoid", "name", "card", "phone", "email", "area", "create_time", "test_type"]);

    let dataTitle = ["姓名", "身份证号", "联系方式", "电子邮箱", "所属区域", "测试日期", "测评类型"];
    let dataList = [dataTitle];
    findData.data.forEach( info => {
        let {name, card, phone, email, area, create_time, test_type} = info;
        let createTime = moment(create_time).format("YYYY-MM-DD");
        let testType = changeEnumValue(TESTTYPE, test_type);
        let subList = [
            name || "", 
            card || "", 
            phone || "", 
            email || "", 
            area || "", 
            createTime || "", 
            testType || ""
        ];
        dataList.push(subList);
    })
    
    return dataList;
}


