/**
 * 霍兰德
 */

import moment from "moment";
import { TABLENAME } from "../config/dbEnum";
import { CHAPTER, HLDTYPE, QUESTION, QUESTIONTITLE, TESTTYPE } from "../config/enum";
import { ERRORENUM } from "../config/errorEnum";
import { addData } from "../data/addData";
import { selectDataListByParam, selectDataToTableAssociation, selectOneDataByParam } from "../data/findData";
import { changeEnumValue, eccEnumValue } from "../tools/eccEnum";
import { BizError } from "../util/bizError";
import { updateManyData } from "../data/updateData";


/**
 * 个人信息填写
 * @param test_type 题目类型：1. 霍兰德
 * @param card 
 * @param name 
 * @param phone 
 * @param area 
 * @param email 非必填，没有传null
 * @returns 
 */
export async function addUsers(testType, name, card, phone, area, email?) {
    let findCardData = await selectOneDataByParam(TABLENAME.测试信息表, {test_type:testType, card}, []);
    // if (findCardData.data.core) throw new BizError(ERRORENUM.该身份证号码重复);

    let addParam = {
        test_type:testType,
        name,
        card,
        phone,
        area,
        test_date:moment(new Date()).format("YYYY-MM-DD 00:00:00")
    };
    if (email) addParam[email] = email;

    if (!findCardData.data.card) {
        await addData(TABLENAME.测试信息表, addParam);
    } else {
        await updateManyData(TABLENAME.测试信息表, {test_type:testType, card}, addParam);
    }

    let userInfo = await selectOneDataByParam(TABLENAME.测试信息表, {test_type:testType, card}, ["infoid", "name"]);
    
    return userInfo.data;
}


/**
 * 下拉选择所属区域
 */
export async function getArea() {
    let findData = await selectDataListByParam(TABLENAME.省市区表, {pid:"310100"}, ["id", "name"]);
    return findData.data;
}


/**
 * 获取题目
 * @param test_type 题目类型：1. 霍兰德 2. 创业
 * @param chapter 章节
 * 1.霍兰德（一、我感兴趣的活动）2.霍兰德（二、我能完成的活动）3.霍兰德（三、我喜欢的职业）
 * 4.霍兰德（四、我的能力类型简评A）5.霍兰德（四、我的能力类型简评B）
 * 6.创业（技能）7.创业（经验）8.创业（您开办的新创业组织）9.创业（创办企业）10.符合你的特点
 * @param isTest 是否演示版 0：否 1：是
 * @returns 
 */
export async function getQuestion(testType, chapter, isTest) {
    if(!testType) testType = 1;
    eccEnumValue("获取题目", "test_type", TESTTYPE, testType);
    eccEnumValue("获取题目", "chapter", CHAPTER, chapter);

    let selectParam:any = {};
    if (testType == TESTTYPE.霍兰德) selectParam = {is_del:0, test_type:1, chapter:1};
    else if (testType == TESTTYPE.创业) selectParam = {is_del:0, test_type:2, chapter:6};

    if (testType) selectParam.test_type = testType;
    if (chapter) selectParam.chapter = chapter;
    /** includeConf:关联表配置*/
    let includeConf = {};
    includeConf[TABLENAME.题目选项表] = {colum:["option_name", "points"], where:{is_del:0} }; // colum：关联表需要查询的字段，where：关联表查询条件

    /** questionInfo：多表联查*/
    let questionInfo = await selectDataToTableAssociation(TABLENAME.题目表, includeConf, selectParam, ["qid", "sort", "chapter", "title"]);
    let questionData = [];
    questionInfo.data.forEach( info => {
        let {qid, title, options} = info;
        let optionList = [];
        options.forEach( option => {
            let {sort, oid, option_name, points} = option;
            optionList.push({oid, optionName:option_name, points, sort});
        })
        let chapter = changeEnumValue(CHAPTER, info.chapter);
        questionData.push({sort:info.sort, qid, chapter, title, option:optionList})
    })

    if (testType == TESTTYPE.创业) questionData = getRandomQuestions(questionData, chapter);
    if (isTest == 1) questionData = getRandomQuestions(questionData, chapter, isTest);
    return questionData;
}


/**
 * 添加测试信息记录
 * @param infoid 测试用户id
 * @param chapter 章节 一个章节一条数据
 * @param option [{ qid:1, answerIds:[1,2,3] }, { qid:2, answerIds:[4,5,6] }, ......]
 * @param test_type 题目类型：1. 霍兰德 2. 创业
 * @param isTest 是否演示版 0：否 1：是
 */
export async function addUsersInfo(infoid, chapter, option, testType, isTest) {
    // if(findData.data && findData.data.length) throw new BizError("不可重复提交"); //判断一个用户一个章节答题不可重复提交

    let addParam = {infoid, chapter, title_str:"", option_str:""}
    let optionData = JSON.parse(option);
    let title_str = [];
    let option_str = [];
    for(let i = 0; i < optionData.length; i++) {
        let info = optionData[i];
        let {qid, answerIds} = info;
        let findData = await selectOneDataByParam(TABLENAME.题目表, {qid}, []);
        let title = "";
        if (testType == TESTTYPE.霍兰德) title = findData.data["title"].charAt(0);
        else if (testType == TESTTYPE.创业) title = findData.data["title"];
        
        title_str.push(title);
        option_str.push(answerIds);
    }

    addParam.title_str = JSON.stringify(title_str);
    addParam.option_str = JSON.stringify(option_str);
    
    if (isTest == 1) await addData(TABLENAME.演示版测试信息记录表, addParam);
    else if (isTest == 0) {
        let findData = await selectDataListByParam(TABLENAME.测试信息记录表, {infoid, chapter}, []);
        if (findData.data && findData.data.length) {
            await updateManyData(TABLENAME.测试信息记录表, {infoid, chapter}, addParam);
        } else {
            await addData(TABLENAME.测试信息记录表, addParam);
        }
    }

    return {isSuccess:true};
}


/**
 * 霍兰德 获取分数
 * @param infoid 测试用户id
 */
export async function getFinalScore(infoid, isTest) {
    let findUserData = await selectOneDataByParam(TABLENAME.测试信息表, {infoid}, []);
    let findData:any = {};
    if (isTest == 1) findData = await selectDataListByParam(TABLENAME.演示版测试信息记录表, {infoid}, []);
    else if (isTest == 0) findData = await selectDataListByParam(TABLENAME.测试信息记录表, {infoid}, []);

    let optionsInfo = {};
    for (let data = 0; data < findData.data.length; data++) {
        let info = findData.data[data];
        let {chapter, title_str, option_str} = info;
        optionsInfo[chapter] = {};
        let title = JSON.parse(title_str);
        let option = JSON.parse(option_str);
        for (let i = 0; i < option.length; i++) {
            let optionList = option[i];
            let score = 0;
            for (let o = 0; o < optionList.length; o++) {
                let findOption = await selectOneDataByParam(TABLENAME.题目选项表, {oid:optionList[o]}, []);
                score += findOption.data["points"];
            }
            optionsInfo[chapter][title[i]] = score;
        }
    }
    
    let optionData = [];
    let countInfo = {};
    for (let key in optionsInfo) {
        let maxKey = "";
        let maxValue = 0;
        for (let values in optionsInfo[key]) {
            const value = optionsInfo[key][values];
            if (value > maxValue) {
                maxKey = values;
                maxValue = value;
            }

            if(!countInfo[values]) countInfo[values] = 0
            countInfo[values] += value;
        }
        let title = changeEnumValue(CHAPTER, parseInt(key));
        let maxNum = HLDTYPE[maxKey];
        optionData.push({key:title, value:maxKey, index:maxNum});
    }
    
    let countData = [];
    for (let key in countInfo) {
        let keyNum = HLDTYPE[key];
        let keyName = changeEnumValue(QUESTION, keyNum);
        countData.push({key:keyName, value:countInfo[key]});
    }

    let sortedEntries:any = Object.entries(countInfo);
    sortedEntries.sort((a, b) => b[1] - a[1]);
    let topThreeKeys = sortedEntries.slice(0, 3).map(entry => entry[0]);
    let topThreeStr = topThreeKeys.join("");
    // let selectParam = {"$and":[]};
    // topThreeKeys.forEach( info => {
    //     selectParam["$and"].push({"statistics":{"%regexp%":`[${info}]`}});
    // })

    let selectParam = {"%literal%":``};
    topThreeKeys.forEach( info => {
        if (!selectParam["%literal%"]) selectParam["%literal%"] = `statistics REGEXP '[${info}]' `;
        selectParam["%literal%"] += `and statistics REGEXP '[${info}]' `;
    })
    let findCareer = await selectDataListByParam(TABLENAME.职业对照表, selectParam, []);

    let testReport = {
        name:findUserData.data.name,
        time: moment(new Date()).format("YYYY年MM月DD日HH时mm分"),
        report1:optionData,
        report2:countData,
        statistics:topThreeStr,
        recommend:""
    }

    findCareer.data.forEach( info => {
        testReport.recommend += info.recommend;
    })

    return testReport;
}


/**
 * 创业 获取分数
 * 评分标准为：A.5分；B.4分；C. 3分；D.2分；E.1分
 * @param infoid 测试用户id
 * @returns 姓名、分数、所有题目和所选答案
 */
export async function getChuangYeScore(infoid, isTest) {
    let findUserData = await selectOneDataByParam(TABLENAME.测试信息表, {infoid}, []);
    let findData:any = {};
    if (isTest == 1) findData = await selectDataListByParam(TABLENAME.演示版测试信息记录表, {infoid}, []);
    else if (isTest == 0) findData = await selectDataListByParam(TABLENAME.测试信息记录表, {infoid}, []);
    
    let optionsInfo = [];
    let score = 0;
    for (let data = 0; data < findData.data.length; data++) {
        let info = findData.data[data];
        let {chapter, title_str, option_str} = info;
        // optionsInfo[chapter] = {};
        let title = JSON.parse(title_str);
        let option = JSON.parse(option_str);
        for (let i = 0; i < option.length; i++) {
            let optionList = option[i];
            let optionName = "";
            for (let o = 0; o < optionList.length; o++) {
                let findOption = await selectOneDataByParam(TABLENAME.题目选项表, {oid:optionList[o]}, []);
                score += findOption.data["points"];
                optionName = findOption.data["option_name"].slice(2); 
            }
            optionsInfo.push({title:title[i], option:optionName});
        }
    }

    let testReport = {
        score,
        name:findUserData.data.name,
        time: moment(new Date()).format("YYYY年MM月DD日HH时mm分"),
        report:optionsInfo,
    }

    if (isTest == 1) testReport.score = 91;

    return testReport;
}


/**
 * 创业 根据不同章节返回不同数量的题目
 * 题目抽取比例为：技能取3题；经验取4题；您开办的新创业组织取5题；创办企业取8题；以下的每一条描述，你觉得它在多大程度上符合你的特点取10题
 * @param data 
 * @param chapter 章节 
 * @returns 
 */
function getRandomQuestions(data, chapter, isTest?) {
    let numberOfQuestions = 0;

    if (chapter == CHAPTER.技能) numberOfQuestions = 3;
    else if (chapter == CHAPTER.经验) numberOfQuestions = 4;
    else if (chapter == CHAPTER.您开办的新创业组织) numberOfQuestions = 5;
    else if (chapter == CHAPTER.创办企业) numberOfQuestions = 8;
    else if (chapter == CHAPTER.符合你的特点) numberOfQuestions = 10;

    if (isTest == 1) numberOfQuestions = 1;

    // 使用 Fisher-Yates 洗牌算法打乱数组
    function shuffleArray(array) {
      for (let i = array.length - 1; i > 0; i--) {
        const j = Math.floor(Math.random() * (i + 1));
        [array[i], array[j]] = [array[j], array[i]]; // 交换元素
      }
      return array;
    }
   
    // 打乱数据集
    const shuffledData = shuffleArray([...data]);
   
    // 返回打乱后的前 numberOfQuestions 个条目
    return shuffledData.slice(0, numberOfQuestions);
}




