import { table } from "console";
import { Association } from "sequelize";

const { Sequelize, DataTypes } = require('sequelize');

export const TablesConfig = [
    {
        tableNameCn:'题目选项表',
        tableName:'option',
        schema:{
            oid: {
                type:DataTypes.INTEGER(11), //表示属性的数据类型
                allowNull:false, //表示当前列是否允许为空， false表示该列不能为空
                primaryKey:true, //表示主键
                unique:true, //表示该列的值必须唯一
                autoIncrement:true //设置为主键并自增
            },
            qid: {type:DataTypes.INTEGER(11)}, //题目ID
            option_name: {type:DataTypes.STRING(255)}, //选项名称
            points: {type:DataTypes.INTEGER(11)}, //分值
            sort: {type:DataTypes.INTEGER(11)}, //排序
            last_update_time: {type:DataTypes.DATE(0)}, //最后修改时间
            create_time: {type:DataTypes.DATE(0)}, //创建时间
            is_del: {type:DataTypes.TINYINT(1)}, //是否删除 0.正常  1.已删除
        },
        association: [
            // {type: "hasMany", check: "question", foreignKey: "qid"}
        ]
    },
    {
        tableNameCn:'题目表',
        tableName:'question',
        schema:{
            qid: {
                type:DataTypes.INTEGER(11), //表示属性的数据类型
                allowNull:false, //表示当前列是否允许为空， false表示该列不能为空
                primaryKey:true, //表示主键
                unique:true, //表示该列的值必须唯一
                autoIncrement:true //设置为主键并自增
            },
            title: {type:DataTypes.STRING(255)}, //题目类型：1. 霍兰德
            test_type: {type:DataTypes.TINYINT(1)}, //章节：1.霍兰德（一、我感兴趣的活动）2.霍兰德（二、我能完成的活动）3.霍兰德（三、我喜欢的职业）4.霍兰德（四、我的能力类型简评A）5.霍兰德（四、我的能力类型简评B）
            chapter: {type:DataTypes.TINYINT(2)}, //章节
            sort: {type:DataTypes.INTEGER(255)}, //排序
            last_update_time: {type:DataTypes.DATE(0)}, //最后修改时间
            create_time: {type:DataTypes.DATE(0)}, //创建时间
            is_del: {type:DataTypes.TINYINT(1)}, //是否删除 0.正常  1.已删除
        },
        association: [
            {type:"hasMany", check:"option", foreignKey:"qid"},
        ]
    },
    {
        tableNameCn:'省市区表',
        tableName:'area',
        schema:{
            id: {
                type:DataTypes.INTEGER(11), //表示属性的数据类型
                allowNull:false, //表示当前列是否允许为空， false表示该列不能为空
                primaryKey:true, //表示主键
                unique:true, //表示该列的值必须唯一
                autoIncrement:true //设置为主键并自增
            },
            pid: {type:DataTypes.INTEGER(11),allowNull:false}, //父级ID  0表示最高节点
            name: {type:DataTypes.STRING(500)}, //名字
            visible: {type:DataTypes.TINYINT(4)}, //是否显示 1.不显示 2.显示
            displayorder: {type:DataTypes.INTEGER(11)}, //显示顺序
            level: {type:DataTypes.TINYINT(3)}, //层级别 1.省 2.市 3.区
            },
            association: [
                // {type: "belongsTo", check: "area", foreignKey:"pid"}
            ]
    },
    {
        tableNameCn:'测试信息表',
        tableName:'testinfo',
        schema:{
            infoid: {
                type:DataTypes.INTEGER(11), //表示属性的数据类型
                allowNull:false, //表示当前列是否允许为空， false表示该列不能为空
                primaryKey:true, //表示主键
                unique:true, //表示该列的值必须唯一
                autoIncrement:true //设置为主键并自增
            },
            test_type: {type:DataTypes.TINYINT(1)}, //题目类型：1. 霍兰德
            name: {type:DataTypes.STRING(255)}, //姓名
            card:{type:DataTypes.STRING(255)},//身份证号
            phone: {type:DataTypes.STRING(255)}, //联系电话
            email: {type:DataTypes.STRING(255)}, //电子邮箱
            area:{type:DataTypes.STRING(255)}, //所在区域
            final_score: {type:DataTypes.INTEGER}, //最终得分
            test_date: {type:DataTypes.DATE}, //测试时间
            last_update_time: {type:DataTypes.DATE,allowNull:false}, //最后修改时间
            create_time: {type:DataTypes.DATE,allowNull:false}, //创建时间
            is_del: {type:DataTypes.TINYINT,allowNull:false}, //是否删除 0.正常  1.已删除
            // highest_letter: {type:DataTypes.TINYINT}, //最高分字母
            // second_highest_letter: {type:DataTypes.TINYINT}, //第二高分字母
            // third_highest_letter: {type:DataTypes.TINYINT}, //第三高分字母  
        },
        association: [
           // { type: "hasMany", check: "inforecord", foreignKey: "infoid" }
        ]
    },
    {
        tableNameCn:'信息记录表',
        tableName:'inforecord',
        schema:{
            irid: {
                type:DataTypes.INTEGER(11), //表示属性的数据类型
                allowNull:false, //表示当前列是否允许为空， false表示该列不能为空
                primaryKey:true, //表示主键
                unique:true, //表示该列的值必须唯一
                autoIncrement:true //设置为主键并自增
            },
            infoid: {type:DataTypes.INTEGER(11),allowNull:false}, //测试信息ID
            chapter: {type:DataTypes.TINYINT(2),allowNull:false}, //章节 1.霍兰德（一、我感兴趣的活动）2.霍兰德（二、我能完成的活动）3.霍兰德（三、我喜欢的职业）4.霍兰德（四、我的能力类型简评A）5.霍兰德（四、我的能力类型简评B）
            title_str: {type:DataTypes.STRING(255),allowNull:false}, //记录标题用逗号隔开
            option_str: {type:DataTypes.STRING(255),allowNull:false}, //记录结果用逗号隔开
            last_update_time: {type:DataTypes.DATE(0),allowNull:false}, //最后修改时间
            create_time: {type:DataTypes.DATE(0),allowNull:false}, //创建时间
            is_del: {type:DataTypes.TINYINT(1),allowNull:false}, //是否删除 0.正常  1.已删除
        },
        association: [
            //{ type: "belongsTo", check: "testinfo", foreignKey: "infoid" }
        ]
    },
    {
        tableNameCn:'测试信息记录表',
        tableName:'inforecord_test',
        schema:{
            irid: {
                type:DataTypes.INTEGER(11), //表示属性的数据类型
                allowNull:false, //表示当前列是否允许为空， false表示该列不能为空
                primaryKey:true, //表示主键
                unique:true, //表示该列的值必须唯一
                autoIncrement:true //设置为主键并自增
            },
            infoid: {type:DataTypes.INTEGER(11),allowNull:false}, //测试信息ID
            chapter: {type:DataTypes.TINYINT(2),allowNull:false}, //章节 1.霍兰德（一、我感兴趣的活动）2.霍兰德（二、我能完成的活动）3.霍兰德（三、我喜欢的职业）4.霍兰德（四、我的能力类型简评A）5.霍兰德（四、我的能力类型简评B）
            title_str: {type:DataTypes.STRING(255),allowNull:false}, //记录标题用逗号隔开
            option_str: {type:DataTypes.STRING(255),allowNull:false}, //记录结果用逗号隔开
            last_update_time: {type:DataTypes.DATE(0),allowNull:false}, //最后修改时间
            create_time: {type:DataTypes.DATE(0),allowNull:false}, //创建时间
            is_del: {type:DataTypes.TINYINT(1),allowNull:false}, //是否删除 0.正常  1.已删除
        },
        association: [
            //{ type: "belongsTo", check: "testinfo", foreignKey: "infoid" }
        ]
    },
    {
        tableNameCn:'职业对照表',
        tableName:'career_contrast',
        schema:{
            cid: {
                type:DataTypes.INTEGER(11), //表示属性的数据类型
                allowNull:false, //表示当前列是否允许为空， false表示该列不能为空
                primaryKey:true, //表示主键
                unique:true, //表示该列的值必须唯一
                autoIncrement:true //设置为主键并自增
            },
            statistics: {type:DataTypes.STRING(255),allowNull:false}, //记录标题用逗号隔开
            recommend: {type:DataTypes.STRING(255),allowNull:false}, //记录结果用逗号隔开
            last_update_time: {type:DataTypes.DATE(0),allowNull:false}, //最后修改时间
            create_time: {type:DataTypes.DATE(0),allowNull:false}, //创建时间
            is_del: {type:DataTypes.TINYINT(1),allowNull:false}, //是否删除 0.正常  1.已删除
        },
        association: [
            //{ type: "belongsTo", check: "testinfo", foreignKey: "infoid" }
        ]
    },
    {
        tableNameCn:'管理员表',
        tableName:'sys_user',
        schema:{
            id: {
                type:DataTypes.INTEGER(11), //表示属性的数据类型
                allowNull:false, //表示当前列是否允许为空， false表示该列不能为空
                primaryKey:true, //表示主键
                unique:true, //表示该列的值必须唯一
                autoIncrement:true //设置为主键并自增
            },
            username: {type:DataTypes.STRING(255),allowNull:false}, //用户名
            password: {type:DataTypes.STRING(255),allowNull:false}, //密码
            real_name: {type:DataTypes.STRING(255),allowNull:false}, //真实姓名
            phone: {type:DataTypes.STRING(255),allowNull:false}, //手机号码
            sex: {type:DataTypes.STRING(255),allowNull:false}, //性别 1、男 2、女
            mail: {type:DataTypes.STRING(255),allowNull:false}, //邮箱
            remark: {type:DataTypes.STRING(255),allowNull:false}, //备注
            create_time: {type:DataTypes.DATE(0),allowNull:false}, //创建时间
            last_update_time: {type:DataTypes.DATE(0),allowNull:false}, //最后修改时间
        },
        association: [
        ]
    }
    
    
]; 